#!/usr/bin/env python3

from testutil import *

from gi.repository import Gio, GLib

import os, time, sys
import pyatspi
from dogtail import tree
from dogtail import utils
from dogtail.procedural import *

init()
try:
    app = start()

    albums_button = app.child('Albums')
    x = y = -1
    while x < 0 and y < 0:
        (x, y) = albums_button.position
        time.sleep(0.1)
    albums_button.click()
    photos_button = app.child('Photos')
    photos_button.click()
    favorites_button = app.child('Favorites')
    favorites_button.click()
finally:
    fini()



#!/usr/bin/env python3

import glob
import os
import re
import subprocess
import sys

destdir = os.environ.get('DESTDIR', '')

if destdir:
    datadir = os.path.normpath(destdir + os.sep + sys.argv[1])
else:
    datadir = sys.argv[1]

icondir = os.path.join(datadir, 'icons', 'hicolor')

name_pattern = re.compile('hicolor_(?:apps)_(?:scalable|symbolic)_(.*)')
search_pattern = '/**/hicolor_*'

for file in glob.glob(icondir + search_pattern, recursive=True):
    os.rename(file, os.path.join(os.path.dirname(file), name_pattern.search(file).group(1)))

if not destdir:
    print('Updating icon cache...')
    subprocess.call(['gtk-update-icon-cache', '-f', '-t', icondir])

    schemadir = os.path.join(datadir, 'glib-2.0', 'schemas')
    print('Compiling gsettings schemas...')
    subprocess.call(['glib-compile-schemas', schemadir])
